@@ -1,5 +1,5 @@
 package HackaMol::Roles::AtomGroupRole;
-$HackaMol::Roles::AtomGroupRole::VERSION = '0.038';
+$HackaMol::Roles::AtomGroupRole::VERSION = '0.039';
 #ABSTRACT: Role for a group of atoms
 use Moose::Role;
 use Carp;
@@ -19,6 +19,7 @@ has 'atoms' => (
     isa     => 'ArrayRef[HackaMol::Atom]',
     default => sub { [] },
     handles => {
+        unshift_atoms => 'unshift',
         push_atoms    => 'push',
         select_atoms  => 'grep',
         map_atoms     => 'map',
@@ -389,7 +390,7 @@ HackaMol::Roles::AtomGroupRole - Role for a group of atoms
 
 =head1 VERSION
 
-version 0.038
+version 0.039
 
 =head1 SYNOPSIS
 
@@ -579,11 +580,14 @@ Returns the offset.
 
 ARRAY traits for the atoms attribute, respectively: push, get, set, elements, count, clear
 
-=head2 push_atoms
+=head2 push_atoms, unshift_atoms
 
-push atom on to atoms array
+push atom on to the end of the atoms array 
+  or 
+unshift_atoms on to the front of the array
 
   $group->push_atoms($atom1, $atom2, @otheratoms);
+  $group->unshift_atoms($atom1, $atom2, @otheratoms); # maybe in reverse
 
 =head2 all_atoms
 
