@@ -1,9 +1,8 @@
 package HackaMol::Roles::NERFRole;
  # ABSTRACT: Role providing Natural extension reference frame implementation for molecular building 
-$HackaMol::Roles::NERFRole::VERSION = '0.038';
+$HackaMol::Roles::NERFRole::VERSION = '0.039';
 use 5.008;
-use Moo::Role;
-use strictures 2;
+use Moose::Role;
 use Math::Vector::Real;
 use Math::Trig; 
 
@@ -52,6 +51,8 @@ sub extend_abc {
   return $D;
 }
 
+no Moose::Role;
+
 1;
 
 __END__
@@ -64,7 +65,7 @@ HackaMol::Roles::NERFRole - Role providing Natural extension reference frame imp
 
 =head1 VERSION
 
-version 0.038
+version 0.039
 
 =head1 SYNOPSIS
 
@@ -85,8 +86,7 @@ version 0.038
 
 The HackaMol::X::NERF library is a quick implementation of the Natural 
 Extension Reference Frame method for building cartesian coordinates from 
-internal coordinates.  This library currently uses Moo and Math::Vector::Real 
-objects, and is thus reasonably fast.  It is experimental. In fact, there are
+internal coordinates.  It is experimental. In fact, there are
 no substantial tests yet! They will be added soon. 
 The API will change and expand.  Currently, the class provides four methods four initializing and extending a vector space. Lend me a hand if you are interested!
 
