@@ -1,8 +1,7 @@
 package HackaMol::Roles::ReadPdbRole;
-$HackaMol::Roles::ReadPdbRole::VERSION = '0.038';
+$HackaMol::Roles::ReadPdbRole::VERSION = '0.039';
 # ABSTRACT: Read files with molecular information
-use Moo::Role;
-use strictures 2;
+use Moose::Role;
 use HackaMol::PeriodicTable qw(_element_name _trim _qstring_num);
 use Math::Vector::Real;
 use Carp;
@@ -118,6 +117,8 @@ sub read_pdb_atoms {
     return (@atoms);
 }
 
+no Moose::Role;
+
 1;
 
 __END__
@@ -130,7 +131,7 @@ HackaMol::Roles::ReadPdbRole - Read files with molecular information
 
 =head1 VERSION
 
-version 0.038
+version 0.039
 
 =head1 SYNOPSIS
 
