@@ -1,8 +1,7 @@
 package HackaMol::Roles::ReadXyzRole;
-$HackaMol::Roles::ReadXyzRole::VERSION = '0.038';
+$HackaMol::Roles::ReadXyzRole::VERSION = '0.039';
 # ABSTRACT: Read files with molecular information
-use Moo::Role;
-use strictures 2; 
+use Moose::Role;
 use Carp;
 use Math::Vector::Real;
 use FileHandle;
@@ -71,6 +70,8 @@ sub read_xyz_atoms {
     return (@atoms);
 }
 
+no Moose::Role;
+
 1;
 
 __END__
@@ -83,7 +84,7 @@ HackaMol::Roles::ReadXyzRole - Read files with molecular information
 
 =head1 VERSION
 
-version 0.038
+version 0.039
 
 =head1 SYNOPSIS
 
