@@ -1,8 +1,7 @@
 package HackaMol::Roles::ReadYAMLRole;
-$HackaMol::Roles::ReadYAMLRole::VERSION = '0.038';
+$HackaMol::Roles::ReadYAMLRole::VERSION = '0.039';
 # ABSTRACT: Read files with molecular information
-use Moo::Role;
-use strictures 2;
+use Moose::Role;
 use HackaMol::PeriodicTable qw(%KNOWN_NAMES _trim);
 use Math::Vector::Real;
 use Carp;
@@ -210,6 +209,8 @@ sub _yaml_substitute_variables{
     return (@Zmat);
 }
 
+no Moose::Role;
+
 1;
 
 __END__
@@ -222,7 +223,7 @@ HackaMol::Roles::ReadYAMLRole - Read files with molecular information
 
 =head1 VERSION
 
-version 0.038
+version 0.039
 
 =head1 SYNOPSIS
 
